diff -Nur RT73_Linux_STA_Drv1.0.4.0.orig/Module/rtmp_def.h RT73_Linux_STA_Drv1.0.4.0/Module/rtmp_def.h
--- RT73_Linux_STA_Drv1.0.4.0.orig/Module/rtmp_def.h	2007-04-26 04:19:42.000000000 +0200
+++ RT73_Linux_STA_Drv1.0.4.0/Module/rtmp_def.h	2007-06-16 16:09:47.000000000 +0200
@@ -156,6 +156,7 @@
 #define fOP_STATUS_DOZE 					0x00000400
 #define fOP_STATUS_MAX_RETRY_ENABLED		0x00000800
 #define fOP_STATUS_RTS_PROTECTION_ENABLE	0x00001000
+#define fOP_STATUS_FIXED_IBSS_BSSID		0x40000000
 
 //
 // Flags for Bulkflags control for bulk out data
diff -Nur RT73_Linux_STA_Drv1.0.4.0.orig/Module/rtmp.h RT73_Linux_STA_Drv1.0.4.0/Module/rtmp.h
--- RT73_Linux_STA_Drv1.0.4.0.orig/Module/rtmp.h	2007-04-26 04:19:42.000000000 +0200
+++ RT73_Linux_STA_Drv1.0.4.0/Module/rtmp.h	2007-06-16 16:09:18.000000000 +0200
@@ -3489,6 +3489,10 @@
 
 #endif  // RALINK_ATE
 
+INT	Set_IBSS_BSSID_Proc(
+	IN	PRTMP_ADAPTER	pAdapter, 
+	IN	PUCHAR			arg);
+
 #if 1
 INT RTMPIoctlSetAuth(	
 	IN	PRTMP_ADAPTER	pAdapter, 
diff -Nur RT73_Linux_STA_Drv1.0.4.0.orig/Module/rtmp_info.c RT73_Linux_STA_Drv1.0.4.0/Module/rtmp_info.c
--- RT73_Linux_STA_Drv1.0.4.0.orig/Module/rtmp_info.c	2007-04-26 04:19:43.000000000 +0200
+++ RT73_Linux_STA_Drv1.0.4.0/Module/rtmp_info.c	2007-06-16 16:08:35.000000000 +0200
@@ -154,6 +154,7 @@
 	{"ATETXCNT",					Set_ATE_TX_COUNT_Proc},     // set ATE TxCount
 	{"ATETXRATE",					Set_ATE_TX_RATE_Proc},      // set ATE TxRate
 #endif	// RALINK_ATE
+	{"IBSS_BSSID",					Set_IBSS_BSSID_Proc},
 	{NULL,}
 };
 
@@ -3842,6 +3843,42 @@
 	return TRUE;
 }
 
+/*
+ * For Freifunk and similar mesh networks: a fixed BSSID
+ * is much better than the holy BSSID split wars commonly
+ * encountered if no fixed BSSID is used in bigger meshes.
+ * Usage: iwpriv rausb0 set IBSS_BSSID=d2:ca:ff:ee:ba:be
+ *        iwpriv rausb0 set IBSS_BSSID=off
+ */
+INT Set_IBSS_BSSID_Proc(
+	IN	PRTMP_ADAPTER	pAdapter, 
+	IN	PUCHAR		arg)
+{
+	int success = FALSE;
+	if (arg)
+	{
+		if (0 == strcmp("off", arg))
+		{
+			OPSTATUS_CLEAR_FLAG(pAdapter, fOP_STATUS_FIXED_IBSS_BSSID);
+		}
+		else
+		{
+			UINT i;
+			for(i = 0; i < ETH_ALEN; i++)
+			{
+				int x = 0;
+				if (arg) sscanf(arg, "%x", &x);
+				pAdapter->PortCfg.Bssid[i] = x;
+				arg = strchr(arg, ':');
+				if (arg) arg++;
+			}
+			OPSTATUS_SET_FLAG(pAdapter, fOP_STATUS_FIXED_IBSS_BSSID);
+		}
+		success = TRUE;
+	}
+	return success;
+}
+
 /* 
 	==========================================================================
 	Description:
diff -Nur RT73_Linux_STA_Drv1.0.4.0.orig/Module/sync.c RT73_Linux_STA_Drv1.0.4.0/Module/sync.c
--- RT73_Linux_STA_Drv1.0.4.0.orig/Module/sync.c	2007-04-26 04:19:43.000000000 +0200
+++ RT73_Linux_STA_Drv1.0.4.0/Module/sync.c	2007-06-16 16:05:48.000000000 +0200
@@ -353,8 +353,15 @@
         NdisMoveMemory(pAd->MlmeAux.Ssid, Ssid, SsidLen); 
         pAd->MlmeAux.SsidLen           = SsidLen;
 
+	if (!OPSTATUS_TEST_FLAG(pAd, fOP_STATUS_FIXED_IBSS_BSSID))
+	{
         // generate a radom number as BSSID
         MacAddrRandomBssid(pAd, pAd->MlmeAux.Bssid);
+	}
+	else
+	{
+		memcpy(pAd->MlmeAux.Bssid, pAd->PortCfg.Bssid, ETH_ALEN);
+	}
 
         Privacy = (pAd->PortCfg.WepStatus == Ndis802_11Encryption1Enabled) || 
                   (pAd->PortCfg.WepStatus == Ndis802_11Encryption2Enabled) || 
@@ -811,6 +818,9 @@
 		is_my_bssid = MAC_ADDR_EQUAL(Bssid, pAd->PortCfg.Bssid)? TRUE : FALSE;
 		is_my_ssid = SSID_EQUAL(Ssid, SsidLen, pAd->PortCfg.Ssid, pAd->PortCfg.SsidLen)? TRUE:FALSE;
 
+		// With a fixed IBSS BSSID, simply ignore all Beacons with another BSSID
+		if (OPSTATUS_TEST_FLAG(pAd, fOP_STATUS_FIXED_IBSS_BSSID) && !is_my_bssid) return;
+
 		// ignore BEACON not for my SSID
 		if ((! is_my_ssid) && (! is_my_bssid))
 			return;
